%global pkgname mongoengine
%global sum A Python Document-Object Mapper for working with MongoDB
%global desc MongoEngine is a Document-Object Mapper (think ORM, \
but for document databases) for working with MongoDB \
from Python. It uses a simple declarative API, similar \
to the Django ORM.


Name: python-%{pkgname}
Version: 0.15.3
Release: 1%{?dist}
BuildArch: noarch

License: MIT
Summary: %{sum}
URL:     http://mongoengine.org/
Source0: https://github.com/MongoEngine/mongoengine/archive/v%{version}/%{pkgname}-%{version}.tar.gz

# pymongo and pymongo-gridfs is needed for the docs
BuildRequires: python-pymongo
BuildRequires: python-pymongo-gridfs
# This is needed for 2to3
BuildRequires: python-tools
BuildRequires: python2-devel
BuildRequires: python2-sphinx
BuildRequires: python3-devel


%description
%{desc}


%package -n python2-%{pkgname}
Summary: %{sum}
Requires: python-blinker
Requires: python2-pillow
Requires: python2-pymongo
Requires: python2-pymongo-gridfs
Requires: python2-six
%{?python_provide:%python_provide python2-%{pkgname}}


%description -n python2-%{pkgname}
%{desc}


%package -n python3-%{pkgname}
Summary: %{sum}
Requires: python3-blinker
Requires: python3-pillow
Requires: python3-pymongo
Requires: python3-pymongo-gridfs
Requires: python3-six
%{?python_provide:%python_provide python3-%{pkgname}}


%description -n python3-%{pkgname}
%{desc}


%package doc
Summary: Documentation for %{name}
BuildArch: noarch


%description doc
Documentation for %{name}.


%prep
%setup -qc
mv %{pkgname}-%{version} python2
pushd python2
# move common doc files to top dir
mv LICENSE ..
mv README.rst ..
popd

cp -a python2 python3
find python3 -name '*.py' | xargs sed -i '1s|^#!.*|#!%{__python3}|'
find python2 -name '*.py' | xargs sed -i '1s|^#!.*|#!%{__python2}|'


%build
pushd python2
%py2_build
popd

pushd python3
%py3_build
PYTHONPATH=$(pwd) make -C docs html
rm -f docs/_build/html/.buildinfo
# Don't ship fonts
rm -rf docs/_build/html/_static/font
popd


%install
pushd python2
%py2_install
popd

pushd python3
%py3_install
popd


%files -n python2-%{pkgname}
%license LICENSE
%doc README.rst
%{python2_sitelib}/%{pkgname}
%{python2_sitelib}/%{pkgname}-*.egg-info


%files -n python3-%{pkgname}
%license LICENSE
%doc README.rst
%{python3_sitelib}/%{pkgname}
%{python3_sitelib}/%{pkgname}-*.egg-info


%files doc
%license LICENSE
%doc python3/docs/_build/html


%changelog
* Sun Jul 29 2018 Randy Barlow <bowlofeggs@fedoraproject.org> - 0.15.3-1
- Update to 0.15.3 (#1597681).
- https://github.com/MongoEngine/mongoengine/blob/v0.15.3/docs/changelog.rst

* Sat Apr 28 2018 Randy Barlow <bowlofeggs@fedoraproject.org> - 0.15.1-1
- Update to 0.15.1 (#1504393).
- https://github.com/MongoEngine/mongoengine/blob/v0.15.1/docs/changelog.rst

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.14.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Jun 03 2017 Randy Barlow <bowlofeggs@fedoraproject.org> - 0.14.0-1
- Update to 0.14.0 (#1442650).

* Wed Apr 12 2017 Randy Barlow <bowlofeggs@fedoraproject.org> - 0.12.0-1
- Update to 0.12.0 (#1440451).
- Use a GitHub URL that gives us a name-version.tar.gz.
- Update the URL to the upstream website.

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 26 2016 Randy Barlow <bowlofeggs@fedoraproject.org> - 0.11.0-1
- Update to 0.11.0 (#1400518).
- Drop fonts from the docs, they aren't needed.
- Add dependency on python-six.

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.10.6-4
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.6-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Jan 25 2016 Randy Barlow <rbarlow@redhat.com> - 0.10.6-1
- Update to 0.10.6.
- Add the license to the doc subpackage.

* Thu Dec 24 2015 Randy Barlow <rbarlow@redhat.com> - 0.10.5-2
- Split package into python2 and python3 variants.

* Wed Dec 23 2015 Randy Barlow <rbarlow@redhat.com> - 0.10.5-1
- Update to version 0.15.5.
- Do not run unit tests. They are truly intiegration tests and depend on a running mongod.
  Additionally, they require python-coverage==3.7.1 and Rawhide currently distributes 4.0.3.
- Remove BuildRequires for the tests.
- Convert the spec file to use the newer Python macros.
- Split the docs out into a subpackage.

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Apr 08 2015 Yohan Graterol <yohangraterol92@gmail.com> - 0.9.0-1
- New release 0.9.0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Aug 26 2013 Yohan Graterol <yohangraterol92@gmail.com> - 0.8.4-1
- New Version
* Mon Aug 12 2013 Yohan Graterol <yohangraterol92@gmail.com> - 0.8.3-1
- New version
* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.9-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Mar 13 2013 Eduardo Echeverria  <echevemaster@gmail.com> - 0.7.9-5
- Fix setup.py (add python-pillow instead python-imaging)

* Mon Jan 28 2013 Yohan Graterol <yohangraterol92@gmail.com> - 0.7.9-4
- Add Requires: pymongo, python-gridfs for f17
- Add Requires: python-pymongo, python-pymongo-gridfs for f18+
- Add Requires: python-blinker, python-imaging

* Sun Jan 27 2013 Yohan Graterol <yohangraterol92@gamil.com> - 0.7.9-3
- Built and included test
- Add BuildRequires: python-django >= 1.3

* Sun Jan 27 2013 Yohan Graterol <yohangraterol92@gmail.com> - 0.7.9-2
- Built and included sphinx docs
- Add BuildRequires: python-sphinx, python-pymongo, pymongo-gridfs
- Add BuildRequires: python-coverage, python-nose

* Thu Jan 17 2013 Yohan Graterol <yohangraterol92@gmail.com> - 0.7.9-1
- Initial packaging
